GroupMember
===================================

.. currentmodule:: alfred3_interact.member

.. autoclass:: GroupMember
   :show-inheritance:




   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
      :toctree:









   .. rubric:: Attributes

   .. autosummary::
      :template: autosummary/attribute.rst
      :toctree:


         ~GroupMember.adata
         ~GroupMember.additional_data
         ~GroupMember.client_data
         ~GroupMember.group_id
         ~GroupMember.matched
         ~GroupMember.metadata
         ~GroupMember.move_history
         ~GroupMember.role
         ~GroupMember.session_data
         ~GroupMember.values
